
********
papa1024
********


===========
Description
===========

papa(爬爬)1024 is the web crawler application of the 1024 forum.
Through this application to learn python, including  string, array, dictionary, class, multithread, multi process and so on. Through this project, we can master various uses of Python.

===========
How to use
===========

please goto project 'HomePage' and look at readme file

